# ANALYSIS FILE ----
#
# This R script contains the analysis required
# to create the flexdashboard app

# LIBRARIES ----
# Visualization
library(plotly)
library(DT)

# Dataset
library(datasets)
data(iris)
head(iris)

# DATA TABLE ----
datatable(
  data = iris,
  options = list(scrollY = 700,
                 lengthMenu = c(50, 100, 150))
)

# CLUSTERING ----
features <- colnames(iris[,1:4])
n_clusters <- 3

clusters <- kmeans(x = iris[features], centers = n_clusters)
clusters$cluster

cluster_data <- iris %>% 
  cbind(clusters$cluster) %>% 
  rename(Cluster = "clusters$cluster") %>% 
  mutate(Cluster = factor(Cluster))

datatable(
  data = cluster_data,
  options = list(scrollY = 700,
                 lengthMenu = c(50, 100, 150))
)

# PLOTTING ----
x = "Sepal.Length"
y = "Petal.Length"
g <- cluster_data %>% 
  ggplot(aes_string(x = x, y = y, color = "Cluster")) +
  geom_point(size = 2) + 
  theme_bw()

ggplotly(g)
